import React from 'react';
import { ReactCodeMirrorProps, ReactCodeMirrorRef } from '@uiw/react-codemirror';
import MarkdownPreview, { MarkdownPreviewProps } from '@uiw/react-markdown-preview';
import { IToolBarProps } from './components/ToolBar';
import './index.less';
export * from './theme';
export * from './commands';
export * from '@uiw/react-markdown-preview';
export declare const scrollerStyle: import("@codemirror/state").Extension;
export interface IMarkdownEditor extends ReactCodeMirrorProps {
    className?: string;
    prefixCls?: string;
    /** The raw markdown that will be converted to html (**required**) */
    value?: string;
    /** Shows a preview that will be converted to html. */
    visible?: boolean;
    visibleEditor?: boolean;
    /** Option to hide the tool bar. */
    hideToolbar?: boolean;
    /** Override the default preview component */
    renderPreview?: (props: MarkdownPreviewProps, initVisible: boolean) => React.ReactNode;
    /** Tool display settings. */
    toolbars?: IToolBarProps['toolbars'];
    /** Tool display settings. */
    toolbarsMode?: IToolBarProps['toolbars'];
    /** [@uiw/react-markdown-preview](https://github.com/uiwjs/react-markdown-preview#options-props) options */
    previewProps?: MarkdownPreviewProps;
    /** replace the default `extensions` */
    reExtensions?: ReactCodeMirrorProps['extensions'];
}
export interface ToolBarProps {
    editor: React.RefObject<ReactCodeMirrorRef>;
    preview: React.RefObject<HTMLDivElement>;
    container: React.RefObject<HTMLDivElement>;
    containerEditor: React.RefObject<HTMLDivElement>;
    editorProps: IMarkdownEditor;
}
export interface MarkdownEditorRef {
    editor: React.RefObject<ReactCodeMirrorRef>;
    preview: React.RefObject<HTMLDivElement> | null;
}
declare const MarkdownEditor: MarkdownEditorComponent;
declare type MarkdownEditorComponent = React.FC<React.PropsWithRef<IMarkdownEditor>> & {
    Markdown: typeof MarkdownPreview;
};
export default MarkdownEditor;
